#
# spec file for package mate-menu
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   mate_menu

Name:           mate-menu
Version:        22.04.2
Release:        1.6
Summary:        Advanced MATE menu
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/ubuntu-mate/mate-menu
Source:         https://github.com/ubuntu-mate/mate-menu/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE mate-menu-yast2-software.patch sor.alexei@meowr.ru -- Use YaST2 and GNOME PackageKit package managers.
Patch0:         mate-menu-yast2-software.patch
# PATCH-FIX-UPSTREAM fix-crash-issue.patch hillwood@opensuse.org -- Fix boo#1189452 for Leap 15.2+
Patch1:         fix-crash-issue.patch
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       glib2-tools
Requires:       gvfs
Requires:       mate-menus
Requires:       mozo
Requires:       python3-Unidecode
Requires:       python3-configobj
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
# Fix boo#1189452
Requires:       python3-pyxdg
Requires:       python3-setproctitle
Requires:       python3-xlib
Requires:       xdg-utils
Recommends:     %{name}-lang
Recommends:     lsb-release
BuildArch:      noarch
%glib2_gsettings_schema_requires

%description
An advanced menu for MATE. Supports filtering, favourites,
autosession, and many other features.

This menu originated in the Linux Mint distribution and has
been ported to other distributions that ship the MATE Desktop
Environment.

%lang_package

%prep
%setup -q
%patch0 -p1
# fix boo#1189452 for Leap 15.2+
%if 0%{?suse_version} <=1500
%patch1 -p1
%endif

sed -i 's/su-to-root/xdg-su/g' %{_name}/execute.py

# Do not use env for python sripts.
sed -i '/^#!/s|env python.*$|python3|' lib/*.py

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

%py3_compile %{buildroot}%{_datadir}/%{name}/plugins/
%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_prefix}/lib/%{name}/
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{_name}-*
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/*
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/org.mate.panel.MateMenuApplet.mate-panel-applet
%dir %{_datadir}/dbus-1/
%dir %{_datadir}/dbus-1/services/
%{_datadir}/dbus-1/services/org.mate.panel.applet.MateMenuAppletFactory.service
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Tue May 10 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 22.04.2
  * Sync translations
  * applications: Allow disabling category hover
* Mon Aug 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix crash (boo#1189452)
  * Add fix-crash-issue.patch for leap
  * Change dependence python3-pyxdg to python3-xdg
* Wed Mar 31 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to version 20.04.3
  * Use GAppInfo to launch applications
  * Fix opening Desktop entries with Path
* Thu Aug 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 20.04.1 (changes since 19.04.0):
  * Add a darker MATE logo.
  * Ensure the name is consistent 'Advanced MATE Menu'.
  * Remove theme and colour customisation.
    This feature adds unnecessary complexity and is mostly useless.
    The applet already adapts to the desktop theme and panel
    colours.
  * Use start-here as the menu icon
    Instead of providing a custom image and then having to override
    it, we set the icon to always be "start-here".
    This way each theme can supply the correct icon without having
    to manually change it.
  * Fix applet tooltip text.
  * The viewport is now coloured consistently with the other
    plugins.
  * The buttons will now have a relief on hover.
  * Icons should render sharply on HiDPI displays.
  * Remove search focus delay.
  * Render search icons as high resolution Cairo surfaces.
  * Check availability of environment variables.
  * Fix transliterated desktop entries in the Applications section.
  * Set window title.
    This fixes issues in which a global menu tries to display
    information about the top-level focused window when the
    mate-menu is open.
  * Update translations.
- Drop support for old openSUSE versions.
- Remove mate-menu-glib-2.48.patch.
* Mon Apr  1 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 19.04.0 (changes since 18.04.3):
  * mate_menu/plugins/recent.py: Replace deprecated gvfs-open call
    by "gio open".
  * Support the new mate-menus 1.22+ API.
  * Port to Python3.
  * Fix Fix icon file types.
  * Use gtk-missing-image to replace application-default-icon
    image.
  * Fix keybindings from swallowing Super+Mouse events.
  * Fix spawning zombie processes.
  * Update translations.
- Remove mate-menu-mate-menus-1.22.patch: fixed upstream.
- Add mate-menu-glib-2.48.patch: Restore GLib 2.48 support.
* Sun Nov 25 2018 sor.alexei@meowr.ru
- Add mate-menu-mate-menus-1.22.patch: Support the mate-menus 1.22+
  API (commit b2ce7a8).
* Sat Nov  3 2018 sor.alexei@meowr.ru
- Update to version 18.04.3 (changes since 18.04.1):
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 18.04.1 (changes since 17.10.8):
  * Search engine icon updates.
  * Use xdg-open, not Caja.
  * Support correct widget sizes for HiDPI displays.
  * Play nice with global keybinding code that uses the same
    modifier key.
  * Update translations.
* Wed Sep 27 2017 sor.alexei@meowr.ru
- Update to version 17.10.8:
  * No changelog available.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 17.10.6:
  * places: Fix desktop button.
  * Allow mate-menu to receive event reports from other windows.
- Remove mate-menu-17.10.5-desktop-button.patch.
* Sat Jun 17 2017 sor.alexei@meowr.ru
- Add mate-menu-17.10.5-desktop-button.patch: Fix desktop button in
  Places (commit 7f904dc).
* Sun Jun 11 2017 sor.alexei@meowr.ru
- Update to version 17.10.5 (changes since 17.10.3):
  * Fix arguments in launchers.
  * Sort applications by relevance when searching.
  * Add exception handling around pointer monitor and keybinder.
  * Revert to using "dock" type.
- Remove mate-menu-17.10.3-fix-launching.patch.
* Sun Jun 11 2017 sor.alexei@meowr.ru
- Update to version 17.10.3:
  * Add DuckDckGo as a web search engine option.
  * Make search engines configurable under
    Preferences -> Applications.
  * Fix missing drag-data-get event handler.
  * Fix launching menu editors.
- Add mate-menu-17.10.3-fix-launching.patch: Fix entries launching
  with arguments.
* Fri Jun  9 2017 sor.alexei@meowr.ru
- Update to version 17.10.2 (changes since 17.10.0):
  * Fix get_origin calls in older Gtk3.
  * Fix keybinding in older Gtk3.
  * Fix popup menus.
  * Fix race condition with dconf on session start.
  * Fix missing custom icon crashing mate-menu.
  * Fix bug where hotkey setting blocks usage in global
    keybindings.
  * Use the Gtk3 bookmarks location.
  * Add `PRELIGHT` state flags to all menu buttons while focused.
  * Fix DnD of favourites.
  * Replace ctypes with setproctitle.
  * Fix some deprecations.
  * Update translations.
* Sat Apr 29 2017 sor.alexei@meowr.ru
- Update to version 17.10.0:
  * Fix reordering of favourites.
  * Fix adding Menu to a left or right panel.
  * Drop Opacity support.
  * Update translations.
* Fri Mar 31 2017 sor.alexei@meowr.ru
- Update to version 17.04.3:
  * Menu icon: Scale SVG files to 22px to prevent them from getting
    too big.
  * Fix launching some Wine applications.
  * Better categories hovering state.
* Sun Mar 19 2017 sor.alexei@meowr.ru
- Update to version 17.04.2 (changes since 16.10.1):
  * Enforce the /usr prefix: code relies on it.
  * Build bytecode for scripts in /usr/lib/mate-menu/.
  * Replace galculator with mate-calc.
  * Try MenuLibre and fallback to Mozo.
  * Update translations.
* Wed Jun  8 2016 sor.alexei@meowr.ru
- Update to version 16.10.1:
  * Fix application popup menu.
  * Don't make huge separators in search suggestions.
  * Use a displayable icon for applet selector.
  * Make mate-menu aware of $XDG_CONFIG_HOME.
  * Have a system colour for the border.
  * Have more fallbacks for Terminal.
  * Add GNOME Software as a Package Manager option.
  * Sort available themes in Menu preferences->Theme.
  * Refresh the applications on icon-theme-changed.
- Remove 0001-xterm-no-symlink-dep.patch: fixed upstream.
- Rebase and rename 0002-yast2-software.patch to
  mate-menu-yast2-software.patch.
* Wed Jun  8 2016 sor.alexei@meowr.ru
- Update to version 16.10.0:
  * Port to Gtk3.
  * Don't crash if there's no PM to show.
  * Drop a broken "add to startup" feature.
- Rebase 0001-xterm-no-symlink-dep.patch, 0002-yast2-software.patch.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency.
- Remove useless libmate-desktop-2-17, libmate-panel-applet-4-1
  dependencies.
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 5.7.1:
  * Fix configuring a custom heading colour (lp#1560332).
  * Display the Software Boutique as package manager if it is
    available (lp#1568170).
  * Ensure the menu is always drawn over existing windows
    (lp#1569563)
- Rebase 0001-xterm-no-symlink-dep.patch, 0002-yast2-software.patch.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 5.7.0 (changes since 5.6.8):
  * Fix mate-menu.py being displayed (lp#1553313).
  * Change window hint to toolbar.
  * Update translations.
- Rebase and rename 0002-xterm-no-symlink-dep.patch to
  0001-xterm-no-symlink-dep.patch.
- Rebase 0002-yast2-software.patch.
* Thu Jan 28 2016 sor.alexei@meowr.ru
- Update to 5.6.8:
  * Fix a crash.
- Remove 0001-fix-path-find.patch: merged upstream.
* Mon Jan 18 2016 sor.alexei@meowr.ru
- Update to 5.6.7:
  * Fix intends in mate-menu execute.py.
  * Do not use mate-folder.png that doesn't exist in freedesktop
    specification.
  * Fix configurator crash due to changes in Gtk 2.24.29.
  * Do not crash if lsb_release is not available (boo#959024).
- Remove 0001-execute-fix.patch, 0001-recent-icon.patch,
  0003-fix-configurator-crash.patch: fixed upstream.
- Add 0001-fix-path-find.patch.
- Only recommend lsb-release.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing lsb-release and python-gobject dependencies
  (boo#959024).
- Add 0003-fix-configurator-crash.patch: fix crash in mate-menu
  configurator.
* Sun Dec 20 2015 sor.alexei@meowr.ru
- Update to 5.6.6.
- Rebase 0001-execute-fix.patch and 0002-yast2-software.patch.
* Fri May  1 2015 sor.alexei@meowr.ru
- Update to 5.6.5a:
  * Remove utility scripts.
  * Update translations.
* Wed Apr  1 2015 sor.alexei@meowr.ru
- Update to 5.6.5:
  * Update translations.
* Tue Mar 17 2015 sor.alexei@meowr.ru
- Initial package.
